@@ -14,6 +14,7 @@ import {
   mergePatientFieldValues,
   mergePatientProgramRegistrationConditions,
   mergePatientProgramRegistrations,
+  refreshMultiChildRecordsForSync,
   reconcilePatientFacilities,
   simpleUpdateModels,
   specificUpdateModels,
@@ -33,6 +34,7 @@ export class PatientMergeMaintainer extends ScheduledTask {
     super(schedule, log, jitterTime, enabled);
     this.config = conf;
     this.models = context.store.models;
+    this.sequelize = context.store.sequelize;
   }
 
   checkModelsMissingSpecificUpdateCoverage() {
@@ -61,7 +63,7 @@ export class PatientMergeMaintainer extends ScheduledTask {
         patients.id = ${tableName}.${patientFieldName} 
         AND patients.merged_into_id IS NOT NULL
         ${additionalWhere}
-      RETURNING patients.id, patients.merged_into_id;
+      RETURNING ${tableName}.id;
     `);
     return result.rows;
   }
@@ -86,33 +88,58 @@ export class PatientMergeMaintainer extends ScheduledTask {
     );
   }
 
+  async updateDependentRecordsForResync(merges) {
+    const encounters = merges['Encounter'] || [];
+    await refreshMultiChildRecordsForSync(this.models.Encounter, encounters);
+
+    // Patient Care Plans
+    const patientCarePlans = merges['PatientCarePlan'] || [];
+    await refreshMultiChildRecordsForSync(this.models.PatientCarePlan, patientCarePlans);
+
+    // Patient Death Data
+    const patientDeathDataRecords = merges['PatientDeathData'] || [];
+    await refreshMultiChildRecordsForSync(this.models.PatientDeathData, patientDeathDataRecords);
+  }
+
   async remergePatientRecords() {
-    // set up an object for counting affected records
-    const counts = {};
-    const updateCounts = (name, records) => {
-      const len = records && records.length;
-      if (len) {
-        counts[name] = len;
-      }
-    };
+    return this.sequelize.transaction(async () => {
+      // set up an object for counting affected records
+      const counts = {};
+      const merges = {};
+      const updateCounts = (name, records) => {
+        const len = records && records.length;
+        if (len) {
+          counts[name] = len;
+        }
+      };
+      const updateMerges = (name, records) => {
+        if (records?.length) {
+          merges[name] = records;
+        }
+      };
 
-    // do all the simple model updates
-    for (const modelName of simpleUpdateModels) {
-      const model = this.models[modelName];
-      const records = await this.mergeAllRecordsForModel(model);
-      updateCounts(modelName, records);
-    }
-
-    // then the model updates that need specific updates:
-    for (const modelName of specificUpdateModels) {
-      const method = this[`specificUpdate_${modelName}`];
-      if (method) {
-        const records = await method.call(this);
+      // do all the simple model updates
+      for (const modelName of simpleUpdateModels) {
+        const model = this.models[modelName];
+        const records = await this.mergeAllRecordsForModel(model);
         updateCounts(modelName, records);
+        updateMerges(modelName, records);
       }
-    }
 
-    return counts;
+      // then the model updates that need specific updates:
+      for (const modelName of specificUpdateModels) {
+        const method = this[`specificUpdate_${modelName}`];
+        if (method) {
+          const records = await method.call(this);
+          updateCounts(modelName, records);
+          updateMerges(modelName, records);
+        }
+      }
+
+      await this.updateDependentRecordsForResync(merges);
+
+      return counts;
+    });
   }
 
   async specificUpdate_Patient() {
@@ -168,8 +195,8 @@ export class PatientMergeMaintainer extends ScheduledTask {
         keepPatientId,
         mergedPatientId,
       );
-      if (mergedPatientDeathData) {
-        records.push(mergedPatientDeathData);
+      if (mergedPatientDeathData?.length) {
+        records.push(...mergedPatientDeathData);
       }
     }
     return records;
