@@ -5,29 +5,10 @@ import { QueryTypes, type Sequelize } from 'sequelize';
 import type { Logger } from 'winston';
 import { selectFacilityIds } from '@tamanu/utils/selectFacilityIds';
 import { NON_LOGGED_TABLES, NON_SYNCING_TABLES } from './constants';
+import { SYNC_TICK_FLAGS } from '../../sync/constants';
 
-const tableNameMatch = (schema: string, table: string, matches: string[]) => {
-  const matchTableSchemas = matches
-    .map((match) => match.split('.'))
-    .map(([excludeSchema, excludeTable]) => ({ schema: excludeSchema, table: excludeTable }));
-  const wholeSchemaMatches = matchTableSchemas
-    .filter(({ table: matchTable }) => matchTable === '*')
-    .map(({ schema: matchSchema }) => matchSchema);
-  if (wholeSchemaMatches.includes(schema)) {
-    return true;
-  }
-
-  return matchTableSchemas.some(
-    ({ schema: matchSchema, table: matchTable }) => schema === matchSchema && table === matchTable,
-  );
-};
-
-export const tablesWithoutColumn = (
-  sequelize: Sequelize,
-  column: string,
-  excludes: string[] = NON_SYNCING_TABLES,
-) => {
-  return sequelize
+const tablesWithoutColumn = (sequelize: Sequelize, column: string) =>
+  sequelize
     .query(
       `
     SELECT
@@ -46,31 +27,30 @@ export const tablesWithoutColumn = (
   `,
       { type: QueryTypes.SELECT, bind: { column, excludes: NON_SYNCING_TABLES } },
     )
-    .then((rows) =>
+    .then(rows =>
       rows
-        .map((row) => ({
+        .map(row => ({
           schema: (row as any).schema as string,
           table: (row as any).table as string,
         }))
-        .filter(({ schema, table }) => !tableNameMatch(schema, table, excludes)),
+        .filter(({ schema, table }) => !NON_SYNCING_TABLES.includes(`${schema}.${table}`)),
     );
-};
 
-export const tablesWithoutTrigger = (
+const tablesWithoutTrigger = (
   sequelize: Sequelize,
   prefix: string,
   suffix: string,
   excludes: string[] = NON_SYNCING_TABLES,
-) => {
-  return sequelize
+) =>
+  sequelize
     .query(
       `
       SELECT
         t.table_schema as schema,
         t.table_name as table
       FROM information_schema.tables t
-      LEFT JOIN information_schema.triggers triggers ON
-        t.table_name = triggers.event_object_table
+      LEFT JOIN information_schema.triggers triggers ON 
+        t.table_name = triggers.event_object_table 
         AND t.table_schema = triggers.event_object_schema
         AND triggers.trigger_name = substring(concat($prefix::text, lower(t.table_name), $suffix::text), 0, 64)
       WHERE
@@ -81,21 +61,20 @@ export const tablesWithoutTrigger = (
     `,
       { type: QueryTypes.SELECT, bind: { prefix, suffix } },
     )
-    .then((rows) =>
+    .then(rows =>
       rows
-        .map((row) => ({
+        .map(row => ({
           schema: (row as any).schema as string,
           table: (row as any).table as string,
         }))
-        .filter(({ schema, table }) => !tableNameMatch(schema, table, excludes)),
+        .filter(({ schema, table }) => !excludes.includes(`${schema}.${table}`)),
     );
-};
 
 const tablesWithTrigger = (
   sequelize: Sequelize,
   prefix: string,
   suffix: string,
-  excludes: string[] = [],
+  excludes: string[] = NON_SYNCING_TABLES,
 ) =>
   sequelize
     .query(
@@ -104,28 +83,24 @@ const tablesWithTrigger = (
         t.table_schema as schema,
         t.table_name as table
       FROM information_schema.tables t
-      LEFT JOIN information_schema.table_privileges privileges
-        ON t.table_name = privileges.table_name AND privileges.table_schema = 'public'
+      JOIN information_schema.triggers triggers ON 
+        t.table_name = triggers.event_object_table 
+        AND t.table_schema = triggers.event_object_schema
+        AND triggers.trigger_name = substring(concat($prefix::text, lower(t.table_name), $suffix::text), 0, 64)
       WHERE
-        EXISTS (
-          SELECT *
-          FROM pg_trigger p
-          WHERE p.tgname = substring(concat($prefix::text, lower(t.table_name), $suffix::text), 0, 64)
-        )
-        AND privileges.privilege_type = 'TRIGGER'
-        AND t.table_schema IN ('public', 'logs')
+        t.table_schema IN ('public', 'logs')
         AND t.table_type != 'VIEW'
-        AND (t.table_schema || '.' || t.table_name) NOT IN ($excludes);
+      GROUP BY t.table_schema, t.table_name -- Group to ensure unique results
     `,
-      { type: QueryTypes.SELECT, bind: { prefix, suffix, excludes } },
+      { type: QueryTypes.SELECT, bind: { prefix, suffix } },
     )
-    .then((rows) =>
+    .then(rows =>
       rows
-        .map((row) => ({
+        .map(row => ({
           schema: (row as any).schema as string,
           table: (row as any).table as string,
         }))
-        .filter(({ schema, table }) => !NON_SYNCING_TABLES.includes(`${schema}.${table}`)),
+        .filter(({ schema, table }) => !excludes.includes(`${schema}.${table}`)),
     );
 
 export async function runPreMigration(log: Logger, sequelize: Sequelize) {
@@ -150,11 +125,11 @@ export async function runPreMigration(log: Logger, sequelize: Sequelize) {
 }
 
 export async function runPostMigration(log: Logger, sequelize: Sequelize) {
-  // add column: holds last update tick, default to -999 (not marked for sync) on facility,
-  // and 0 (will be caught in any initial sync) on central server
+  // add column: holds last update tick, default to 0 (will be caught in any initial sync) on central server
+  // and SYNC_TICK_FLAGS.UPDATED_ELSEWHERE (not marked for sync) on facility
   // triggers will overwrite the default for future data, but this works for existing data
   const isFacilityServer = !!selectFacilityIds(config);
-  const initialValue = isFacilityServer ? -999 : 0; // -999 on facility, 0 on central server
+  const initialValue = isFacilityServer ? SYNC_TICK_FLAGS.LAST_UPDATED_ELSEWHERE : 0;
   for (const { schema, table } of await tablesWithoutColumn(sequelize, 'updated_at_sync_tick')) {
     log.info(`Adding updated_at_sync_tick column to ${schema}.${table}`);
     await sequelize.query(`
@@ -171,7 +146,7 @@ export async function runPostMigration(log: Logger, sequelize: Sequelize) {
         type: QueryTypes.SELECT,
         bind: { name },
       })
-      .then((rows) => (rows?.[0] as any)?.count > 0);
+      .then(rows => (rows?.[0] as any)?.count > 0);
 
   // add trigger: before insert or update, set updated_at (overriding any that is passed in)
   if (await functionExists('set_updated_at_sync_tick')) {
